@@ -372,11 +372,11 @@ static int process(FILE * input_des, FILE * output_des, int mode, int block_size
     if(verbose) {
         if(file_name) fprintf(stderr, " %s:", file_name);
         if(mode == MODE_ENCODE)
-            fprintf(stderr, "\t%ld -> %ld bytes, %.2f%%, %.2f bpb\n", bytes_read, bytes_written, (double)bytes_written * 100.0 / bytes_read, (double)bytes_written * 8.0 / bytes_read);
+            fprintf(stderr, "\t%"PRIu64" -> %"PRIu64" bytes, %.2f%%, %.2f bpb\n", bytes_read, bytes_written, (double)bytes_written * 100.0 / bytes_read, (double)bytes_written * 8.0 / bytes_read);
         else if(mode == MODE_DECODE)
-            fprintf(stderr, "\t%ld -> %ld bytes, %.2f%%, %.2f bpb\n", bytes_read, bytes_written, (double)bytes_read * 100.0 / bytes_written, (double)bytes_read * 8.0 / bytes_written);
+            fprintf(stderr, "\t%"PRIu64" -> %"PRIu64" bytes, %.2f%%, %.2f bpb\n", bytes_read, bytes_written, (double)bytes_read * 100.0 / bytes_written, (double)bytes_read * 8.0 / bytes_written);
         else
-            fprintf(stderr, "OK, %ld bytes read.\n", bytes_read);
+            fprintf(stderr, "OK, %"PRIu64" bytes read.\n", bytes_read);
     }
 
     return 0;
@@ -533,9 +533,6 @@ int main(int argc, char * argv[]) {
         }
     }
 
-#ifndef O_BINARY
-    #define O_BINARY 0
-#endif
 #if defined(__MSVCRT__)
     setmode(STDIN_FILENO, O_BINARY);
     setmode(STDOUT_FILENO, O_BINARY);
